
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt
from scipy.stats import gaussian_kde

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)
# Generate random data to simulate the plot
data_cityA = np.random.normal(25, 5, 50)  # City A temperatures around 25C with standard deviation of 5
data_cityB = np.random.normal(30, 5, 50)  # City B temperatures around 30C with standard deviation of 5

# Combine data into a list
weather_data = [data_cityA, data_cityB]

# Create positions for each box plot
positions = [0, 1]
xticks = ["City A", "City B"]
xlabel = "Cities"
ylabel = "Temperature (°C)"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Set the figure size to a suitable dimension
plt.figure(figsize=(8, 6))

# Calculate the kernel density estimate and plot the density plot for each dataset
colors = ["#3A86FF", "#FF006E"]  # Use distinctive, aesthetically pleasing colors
for i, d in enumerate(weather_data):
    # Calculate KDE
    kde = gaussian_kde(d)
    # Create an array of values covering the entire range of data for KDE
    kde_x = np.linspace(min(d), max(d), 300)
    kde_y = kde(kde_x)
    # Scale KDE values to match the position of the boxplot
    kde_y_scaled = kde_y / kde_y.max() * 0.1  # Scale factor can be adjusted
    # Plot filled density plot to the left of the boxplot
    offset = 0.2
    plt.fill_betweenx(
        kde_x,
        positions[i] - kde_y_scaled - offset,
        positions[i] - offset,
        color=colors[i],
        edgecolor="black",
        alpha=0.6
    )

# Create box plots inside the violin plots
for i, d in enumerate(weather_data):
    plt.boxplot(
        d,
        positions=[positions[i]],
        widths=0.15,
        patch_artist=True,
        medianprops=dict(color="black"),
        boxprops=dict(facecolor="white", color="black"),
    )

# Add scatter plot for individual data points with grey color
for i, d in enumerate(weather_data):
    x = np.random.normal(positions[i], 0.04, size=len(d))
    plt.scatter(x, d, color=colors[i], s=10, alpha=0.7)

# Set the x-axis labels and add title
plt.xticks([0, 1], xticks)
plt.xlabel(xlabel)

# Set the y-axis label
plt.ylabel(ylabel)

# Adjust the y-axis limits
plt.ylim(10, 40)

# Add a title to the plot
plt.title("Temperature Comparison Between Two Cities")

# ===================
# Part 4: Saving Output
# ===================
# Show the plot with tight layout to minimize white space
plt.tight_layout()
plt.savefig("CB_76.pdf", bbox_inches="tight")
