
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(42)
# New Data for Psychology Domain (Publishing Frequency)
months = [
    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
    "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
]
cognitive_psychology = np.random.randint(10, 30, size=len(months))
developmental_psychology = np.random.randint(8, 25, size=len(months))
social_psychology = np.random.randint(5, 20, size=len(months))

# Calculate cumulative values for stacked area chart
cumulative_cognitive = cognitive_psychology
cumulative_developmental = cumulative_cognitive + developmental_psychology
cumulative_social = cumulative_developmental + social_psychology

# Positions for the bars on the x-axis
ind = np.arange(len(months))

# Variables for plot configuration
cognitive_label = "Cognitive Psychology"
developmental_label = "Developmental Psychology"
social_label = "Social Psychology"
xlabel_text = "Months"
ylabel_text = "Publishing Frequency"
title_text = "Monthly Publishing Frequency of Psychological Works"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
xlim_values = (0, 11)
ylim_values = (0, max(cumulative_social) + 10)
yticks_values = range(0, max(cumulative_social) + 10, 10)

legend_location = "upper center"
legend_fontsize = 10
legend_frameon = True
legend_shadow = False
legend_facecolor = "#f9f9f9"
legend_ncol = 3
legend_bbox_to_anchor = (0.5, 1.15)
title_fontsize = 16
title_y = 1.2
xlabel_fontsize = 14
ylabel_fontsize = 14
tick_params_color = "gray"
grid_linestyle = "--"
grid_alpha = 0.5

# Plot
fig, ax = plt.subplots(figsize=(10, 5))  # Adjusted for better aspect ratio
ax.fill_between(
    months, 0, cumulative_cognitive, label=cognitive_label, color="#7B68EE", alpha=0.7
)
ax.fill_between(
    months,
    cumulative_cognitive,
    cumulative_developmental,
    label=developmental_label,
    color="#6A5ACD",
    alpha=0.7,
)
ax.fill_between(
    months,
    cumulative_developmental,
    cumulative_social,
    label=social_label,
    color="#483D8B",
    alpha=0.7,
)

# Enhancing the plot with additional visuals
ax.spines["top"].set_visible(False)
ax.spines["right"].set_visible(False)
ax.spines["left"].set_visible(False)
ax.spines["bottom"].set_visible(False)
ax.set_yticks(yticks_values)
# Setting the x-axis and y-axis limits dynamically
ax.set_ylim(*ylim_values)  # Ensure all data fits well
ax.set_xlim(*xlim_values)
# Labels, Title and Grid
ax.set_xlabel(xlabel_text, fontsize=xlabel_fontsize)
ax.set_ylabel(ylabel_text, fontsize=ylabel_fontsize)
ax.set_title(title_text, fontsize=title_fontsize, y=title_y)
ax.tick_params(axis="both", which="both", color=tick_params_color)
# Custom legend
ax.legend(
    loc=legend_location,
    fontsize=legend_fontsize,
    frameon=legend_frameon,
    shadow=legend_shadow,
    facecolor=legend_facecolor,
    ncol=legend_ncol,
    bbox_to_anchor=legend_bbox_to_anchor,
)

# Grid
ax.grid(True, linestyle=grid_linestyle, alpha=grid_alpha, which="both")

# ===================
# Part 4: Saving Output
# ===================
# Adjusting layout to reduce white space
plt.tight_layout()
plt.savefig("area_57.pdf", bbox_inches="tight")
