
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)
months = np.arange(1, 13)
emissions_data = {
    "CO2": np.random.uniform(300, 600, size=12),
    "CH4": np.random.uniform(100, 300, size=12),
    "N2O": np.random.uniform(50, 200, size=12),
    "HFCs": np.random.uniform(10, 100, size=12),
    "PFCs": np.random.uniform(5, 50, size=12),
}

# Extracted variables
legend_labels = list(emissions_data.keys())
xlabel_value = "Month"
ylabel_value = "Emissions (kt)"
title_value = "Monthly Greenhouse Gas Emissions"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
xlim_values = (1, 12)
ylim_values = (0, 1500)
legend_loc = "upper left"
legend_reverse = True
legend_frameon = True
legend_ncol = 1
legend_bbox_to_anchor = (1, 1)
title_y_position = 1.05
colors = ["#1f77b4", "#ff7f0e", "#2ca02c", "#d62728", "#9467bd"]
fig, ax = plt.subplots(figsize=(12, 8))
ax.stackplot(
    months,
    emissions_data.values(),
    labels=legend_labels,
    alpha=0.85,
    colors=colors,
)
ax.legend(
    loc=legend_loc,
    reverse=legend_reverse,
    frameon=legend_frameon,
    ncol=legend_ncol,
    bbox_to_anchor=legend_bbox_to_anchor,
)
ax.set_xlim(*xlim_values)
ax.set_ylim(*ylim_values)
ax.set_title(title_value, y=title_y_position)
ax.set_xlabel(xlabel_value)
ax.set_ylabel(ylabel_value)
ax.grid(True, linestyle='--', linewidth=0.5, alpha=0.7)
ax.tick_params(axis="both", which="both", length=0)

# ===================
# Part 4: Saving Output
# ===================
plt.tight_layout()
plt.savefig("area_70.pdf", bbox_inches="tight")
