
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(78)
# Synthetic data to create contour lines for social trend analysis
x = np.linspace(1950, 2050, 150)
y = np.linspace(0, 100, 150)
X, Y = np.meshgrid(x, y)
Z1 = np.exp(-((X - 1980) ** 2 + (Y - 20) ** 2) / 400)
Z2 = np.exp(-((X - 2020) ** 2 + (Y - 70) ** 2) / 300)

# Labels and texts
labels = ["Population Growth", "Urbanization Rate"]
xlabel = "Year"
ylabel = "Rate (%)"
title = "Social Trend Analysis"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
legend_loc = "upper right"
legend_fontsize = 10
xlabel_fontsize = 12
ylabel_fontsize = 12
title_fontsize = 16
fontweight = "bold"

# Create the plot
fig, ax = plt.subplots(figsize=(12, 10))

# Contour lines for Population Growth (green) and Urbanization Rate (orange)
CS1 = ax.contour(
    X, Y, Z1, colors="green", linestyles="-", linewidths=1.5, label=labels[0]
)
CS2 = ax.contour(
    X, Y, Z2, colors="orange", linestyles="--", linewidths=1.5, label=labels[1]
)

# Labels for x and y axes
plt.xlabel(xlabel, fontsize=xlabel_fontsize, fontweight=fontweight)
plt.ylabel(ylabel, fontsize=ylabel_fontsize, fontweight=fontweight)

# Adding a legend manually
h1, _ = CS1.legend_elements()
h2, _ = CS2.legend_elements()
ax.legend([h1[0], h2[0]], labels, loc=legend_loc, fontsize=legend_fontsize)

# Set the aspect of the plot to match the original image
ax.set_aspect("auto")
ax.grid(True)
ax.set_facecolor("#f5f5f5")  # Very light gray background
ax.set_xlim(1950, 2050)
ax.set_ylim(0, 100)

# Title of the plot
plt.title(title, fontsize=title_fontsize, fontweight=fontweight)

# ===================
# Part 4: Saving Output
# ===================
# Show the plot with tight layout to minimize white space
plt.tight_layout()
plt.savefig("contour_78.pdf", bbox_inches="tight")
