

# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import networkx as nx
import numpy as np

# Create a directed graph
G = nx.DiGraph()

# Add nodes with their respective colors and labels
nodes = {
    0: ("Region A", "mediumturquoise"),
    1: ("Region B", "orchid"),
    2: ("Region C", "lightcoral"),
    3: ("Region D", "wheat"),
    4: ("Region E", "palegoldenrod"),
    5: ("Region F", "lightseagreen"),
}
for node, (label, color) in nodes.items():
    G.add_node(node, label=label, color=color)

# Add edges with labels
edges = [
    (0, 1, "to Region B"),
    (1, 2, "to Region C"),
    (2, 3, "to Region D"),
    (3, 4, "to Region E"),
    (4, 5, "to Region F"),
]
for u, v, label in edges:
    G.add_edge(u, v, label=label)

# Define node positions in a spiral layout
pos = nx.spring_layout(G, seed=42)

title = "Population Migration Flow"


# ===================
# Part 3: Plot Configuration and Rendering
# ===================
fig, ax = plt.subplots(figsize=(10, 10))

# Draw nodes with color attribute
node_colors = [G.nodes[node]["color"] for node in G.nodes]
nx.draw_networkx_nodes(G, pos, node_color=node_colors, node_size=7000, ax=ax)

# Draw edges with arrows
nx.draw_networkx_edges(G, pos, arrowstyle="->", arrowsize=20, ax=ax, edge_color="gray", style="dashed", width=2)

# Draw node labels
node_labels = {node: G.nodes[node]["label"] for node in G.nodes}
nx.draw_networkx_labels(
    G,
    pos,
    labels=node_labels,
    font_size=12,
    font_color="black",
    font_weight="bold",
    ax=ax,
)

# Draw edges with labels
edge_labels = {(u, v): G[u][v]["label"] for u, v in G.edges}
nx.draw_networkx_edge_labels(G, pos, edge_labels=edge_labels, font_size=10, ax=ax)

# Add a title
plt.title(title, size=15, fontweight="bold")

# Remove axis
plt.axis("off")

# ===================
# Part 4: Saving Output
# ===================
# Displaying the plot with tight layout to minimize white space
plt.tight_layout()
plt.savefig("graph_39.pdf", bbox_inches="tight")

