
# ===================
# Part 1: Importing Libraries
# ===================

import matplotlib.pyplot as plt
from matplotlib.lines import Line2D

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)

# Data for Younger Audience and Older Audience
values_younger = [0.85, 0.6, 0.5, 0.9, 0.8, 0.95, 0.75, 0.7, 0.55, 0.8]
values_older = [0.5, 0.7, 0.85, 0.4, 0.3, 0.4, 0.3, 0.75, 0.6, 0.5]
labels = [
    "TV",
    "Radio",
    "Newspapers",
    "Online\nNews",
    "Podcasts",
    "Social\nMedia",
    "Streaming\nServices",
    "Books",
    "Magazines",
    "Movies",
]
num_vars = len(labels)

# Compute angle for each axis
angles = np.linspace(0, 2 * np.pi, num_vars, endpoint=False).tolist()

# The plot is circular, so we need to "complete the loop" and append the start to the end.
values_younger += values_younger[:1]
values_older += values_older[:1]
angles += angles[:1]

# Extracted variables
younger_label = "Younger Audience"
older_label = "Older Audience"
xticks = angles[:-1]
xticklabels = labels
yticklabels = []
rgrids = [0.2, 0.4, 0.6, 0.8, 1.0]
rgrid_labels = ["0.2", "0.4", "0.6", "0.8", "1.0"]
title_text = "Media Consumption Habits: Younger vs Older Audience"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Draw the radar chart
fig, ax = plt.subplots(figsize=(8, 8), subplot_kw=dict(polar=True))

title_size = 18
title_color = "darkblue"
title_y = 1.1

ax.fill(angles, values_younger, color="lightblue", alpha=0.7)
ax.plot(
    angles,
    values_younger,
    color="blue",
    linewidth=2,
    linestyle="-",
    label=younger_label,
)
ax.scatter(angles[:-1], values_younger[:-1], color="blue", s=75, zorder=5, marker="o")

ax.fill(angles, values_older, color="lightgreen", alpha=0.7)
ax.plot(
    angles,
    values_older,
    color="green",
    linewidth=2,
    linestyle="--",
    label=older_label,
)
ax.scatter(
    angles[:-1], values_older[:-1], color="green", s=75, zorder=5, marker="s"
)

# Add labels to the plot
ax.set_xticks(xticks)
ax.set_xticklabels(xticklabels, size=13)

# Add grid lines and labels for the concentric circles
ax.set_yticklabels(yticklabels)
ax.set_rgrids(rgrids, labels=rgrid_labels, angle=225, color="gray", size=12)

# Create legend handles manually
legend_elements = [
    Line2D(
        [0],
        [0],
        color="blue",
        linewidth=2,
        linestyle="-",
        marker="o",
        markersize=10,
        label=younger_label,
    ),
    Line2D(
        [0],
        [0],
        color="green",
        linewidth=2,
        linestyle="--",
        marker="s",
        markersize=10,
        label=older_label,
    ),
]

# Add legend and title
ax.set_title(title_text, size=title_size, color=title_color, y=title_y)
ax.legend(
    handles=legend_elements,
    loc="lower center",
    bbox_to_anchor=(0.5, -0.2),
    frameon=False,
    ncol=2,
)

ax.xaxis.set_tick_params(pad=20)

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout and save the plot
plt.tight_layout()
plt.savefig("radar_74.pdf", bbox_inches="tight")

