
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)

# Simulate some data for the scatter plot representing different financial metrics
n_points = 200
stock_a_x = np.random.normal(0.1, 0.02, n_points)
stock_a_y = np.random.normal(0.15, 0.02, n_points)
stock_b_x = np.random.normal(0.25, 0.03, n_points)
stock_b_y = np.random.normal(0.1, 0.03, n_points)
stock_c_x = np.random.normal(0.5, 0.04, n_points)
stock_c_y = np.random.normal(0.2, 0.04, n_points)
stock_d_x = np.random.normal(0.7, 0.05, n_points)
stock_d_y = np.random.normal(0.25, 0.05, n_points)

xlabel = "Annual Return"
ylabel = "Volatility"
title = "Stock Performance Distribution"

legend_title = "Stocks"

labels = ["Stock A", "Stock B", "Stock C", "Stock D"]

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Create the scatter plot
plt.figure(figsize=(10, 10))
plt.scatter(
    stock_a_x, stock_a_y, color="#FF5733", alpha=0.6, marker="o", label=labels[0]
)
plt.scatter(stock_b_x, stock_b_y, color="#33FF57", alpha=0.6, marker="^", label=labels[1])
plt.scatter(
    stock_c_x, stock_c_y, color="#3357FF", alpha=0.6, marker="s", label=labels[2]
)
plt.scatter(
    stock_d_x,
    stock_d_y,
    color="#FF33A1",
    alpha=0.6,
    marker="x",
    label=labels[3],
)

# Add labels and title
plt.xlabel(xlabel)
plt.ylabel(ylabel)
plt.title(title, fontsize=16)
plt.legend(
    title=legend_title,
    ncol=2,
    bbox_to_anchor=(0.5, 1.05),
    loc="lower center",
    frameon=False,
    fontsize=10,
)
plt.grid(True, linestyle="--", alpha=0.5)
plt.tick_params(
    axis="both", length=6, width=2, colors="gray", grid_color="gray", grid_alpha=0.5
)

# ===================
# Part 4: Saving Output
# ===================
# Show the plot with tight layout
plt.tight_layout()
plt.savefig("scatter_49.pdf", bbox_inches="tight")
