
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np
# Data for plotting
review_round = np.arange(1, 6)
action_ratings = [3.8, 4.0, 3.9, 4.1, 4.2]
comedy_ratings = [4.2, 4.3, 4.1, 4.4, 4.3]
drama_ratings = [4.5, 4.6, 4.7, 4.6, 4.8]

# Labels and Titles
xlabel = "Review Round"
ylabel = "Average Movie Rating"
title = "Movie Ratings Comparison Across Genres"

# Legend labels
action_label = "Action"
comedy_label = "Comedy"
drama_label = "Drama"

# Plot limits
xlim_values = (0.5, 5.5)
ylim_values = (3.5, 5.0)

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Set figure size
plt.figure(figsize=(10, 7))

# Plotting the data with customized marker sizes and colors
plt.scatter(
    review_round,
    action_ratings,
    label=action_label,
    color="#5DADE2",  # Soft blue
    clip_on=False,
    zorder=10,
    marker="o",
    s=200,
    edgecolor='k'
)
plt.scatter(
    review_round,
    comedy_ratings,
    label=comedy_label,
    clip_on=False,
    zorder=10,
    color="#58D68D",  # Soft green
    marker="s",
    s=200,
    edgecolor='k'
)
plt.scatter(
    review_round,
    drama_ratings,
    label=drama_label,
    clip_on=False,
    zorder=10,
    color="#AF7AC5",  # Soft purple
    marker="^",
    s=200,
    edgecolor='k'
)

# Adding labels and title
plt.xlabel(xlabel)
plt.ylabel(ylabel)
plt.title(title, y=1.03)

# Adding a legend
handles, labels = plt.gca().get_legend_handles_labels()
order = [0, 1, 2] 
plt.legend(
    [handles[idx] for idx in order], 
    [labels[idx] for idx in order],
    loc="best",
    ncol=3,
    frameon=True,
    framealpha=0.5
)

plt.xlim(*xlim_values)
plt.ylim(*ylim_values)

# Show grid
plt.grid(True, linestyle='--', alpha=0.7)

# ===================
# Part 4: Saving Output
# ===================
# Show the plot with tight layout to minimize white space
plt.tight_layout()
plt.savefig("scatter_63.pdf", bbox_inches="tight")
