
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt


# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)
# Data for the plots
roles = ["wheat", "corn", "soy"]
counts_s1 = np.array([[120, 230, 450], [160, 270, 370], [210, 390, 300]])
counts_s2 = np.array([[140, 260, 400], [110, 340, 350], [240, 310, 250]])

# Variables for plot configuration
xlabel_value = "Yield (metric tons)"
ylabel_value = "Crop"
title_s1 = "Summer Yields"
title_s2 = "Winter Yields"
legend_labels = ["Region A", "Region B", "Region C"]
fig_title = "Crop Yield Comparison by Season"


# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Colors for the bars
colors = ["#8ca252", "#d8b365", "#e5e5e5"]
width = 0.3
xlim_value = (0, 800)
xticks_value = [0, 100, 200, 300, 400, 500, 600, 700, 800]
yticks_value = roles
fontsize_title = 16

# Create subplots with shared x-axis
fig, (ax1, ax2) = plt.subplots(2, 1, figsize=(10, 8), sharex=True)


# Function to plot stacked bars
def plot_stacked_bars(ax, counts, roles, colors):
    bottom = np.zeros(len(roles))
    for i in range(counts.shape[1]):
        ax.barh(
            roles, counts[:, i], height=width, zorder=5, left=bottom, color=colors[i]
        )
        bottom += counts[:, i]


# Plot for Summer Yields
plot_stacked_bars(ax1, counts_s1, roles, colors)
ax1.set_title(title_s1)
ax1.set_xlabel(xlabel_value)
ax1.set_ylabel(ylabel_value)
ax1.invert_yaxis()  # Invert y-axis to match the picture
ax1.grid(True, alpha=0.7, linestyle='--', linewidth=0.7)  # Add grid lines
ax1.set_xlim(*xlim_value)
ax1.tick_params(axis="y", which="both", length=0)
ax1.tick_params(axis="x", which="both", color="gray")

# Plot for Winter Yields
plot_stacked_bars(ax2, counts_s2, roles, colors)
ax2.set_title(title_s2)
ax2.set_xlabel(xlabel_value)
ax2.set_ylabel(ylabel_value)
ax2.set_xlim(*xlim_value)
ax2.invert_yaxis()  # Invert y-axis to match the picture
ax2.grid(True, alpha=0.7, linestyle='--', linewidth=0.7)  # Add grid lines
ax2.tick_params(axis="y", which="both", length=0)
ax2.tick_params(axis="x", which="both", color="gray")

# Legend
ax1.legend(
    legend_labels,
    bbox_to_anchor=(0.5, 1.2),
    loc="upper center",
    ncol=3,
    frameon=False,
)

# Set x-axis ticks after all plots
ax1.set_xticks(xticks_value)
ax2.set_xticks(xticks_value)
ax1.tick_params(axis="x", which="both", bottom=True, top=False, labelbottom=True)

# Title for the whole figure
fig.suptitle(fig_title, fontsize=fontsize_title)

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout
plt.tight_layout()
plt.savefig("bar_126.pdf", bbox_inches="tight")

