
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
# Data
import numpy as np

np.random.seed(0)

# New categories for geography domain
categories = ["Africa", "Asia", "Europe", "North America", "Oceania", "South America"]
# Generate three lists
PopulationDensity, GDPGrowth, LiteracyRate = np.random.dirichlet(np.ones(3), size=len(categories)).T

PopulationDensity = PopulationDensity * 100
GDPGrowth = GDPGrowth * 100
LiteracyRate = LiteracyRate * 100

# Labels and other text-related parameters
labels = ["Population Density", "GDP Growth", "Literacy Rate"]
yticks = np.arange(0, 101, 20)
ylim = [0, 100]
xlabel = "Continents"
ylabel = "Percentage"
title = "Geographical Metrics by Continent"

legend_loc = "upper center"
legend_bbox_to_anchor = (0.5, 1.15)
legend_ncol = 3

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Stacked bar chart setup
bar_width = 0.9
r = np.arange(len(categories))

# Plot
fig, ax = plt.subplots(figsize=(10, 6))
bar1 = ax.bar(
    r,
    PopulationDensity,
    color="#89c1a8",
    edgecolor="white",
    hatch="++",
    width=bar_width,
    label=labels[0],
)
bar2 = ax.bar(
    r,
    GDPGrowth,
    bottom=PopulationDensity,
    color="#ffb75d",
    edgecolor="white",
    hatch="--",
    width=bar_width,
    label=labels[1],
)
bar3 = ax.bar(
    r,
    LiteracyRate,
    bottom=PopulationDensity + GDPGrowth,
    color="#5ba3ff",
    edgecolor="white",
    hatch="\\\\\\",
    width=bar_width,
    label=labels[2],
)

ax.set_xticks(r)
ax.set_xticklabels(categories, rotation=0, ha="center")
ax.set_yticks(yticks)
ax.set_ylim(ylim)
ax.set_yticklabels(["{}%".format(i) for i in range(0, 101, 20)])
ax.set_xlabel(xlabel)
ax.set_ylabel(ylabel)
ax.set_title(title)
ax.legend(loc=legend_loc, bbox_to_anchor=legend_bbox_to_anchor, ncol=legend_ncol)

ax.spines["top"].set_visible(False)
ax.spines["right"].set_visible(False)
ax.spines["left"].set_visible(False)
ax.spines["bottom"].set_visible(False)
# Grid lines
ax.yaxis.grid(True, linestyle="--", color="gray")

# ===================
# Part 4: Saving Output
# ===================
# Show plot
plt.tight_layout()
plt.savefig("bar_293.pdf", bbox_inches="tight")
