
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)
categories = [
    "Wheat Yield",
    "Corn Yield",
    "Rice Yield",
    "Soybean Yield",
    "Barley Yield",
    "Cotton Yield",
]

means = np.random.uniform(2.0, 6.0, len(categories))  # Yield in tons per hectare
std_devs = np.random.uniform(0.3, 0.7, len(categories))
dataset_mean = np.mean(means)

# Labels and Plot Types
label_Mean = "Mean Yield"
label_Dataset_mean = "Average Yield"

# Axes Limits and Labels
ylabel_value = "Yield (Tons per Hectare)"


title = "Agricultural Yield by Crop Type"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Create figure and axis
fig, ax = plt.subplots(figsize=(10, 6))
ylim_values = [0.0, 7]
# Error bar plot with optimized style
ax.errorbar(
    categories,
    means,
    yerr=std_devs,
    fmt="o",
    color="forestgreen",
    ecolor="darkorange",
    elinewidth=2,
    capsize=5,
    markerfacecolor="limegreen",
    label=label_Mean,
)

# Dataset mean line
ax.axhline(
    y=dataset_mean,
    color="maroon",
    linestyle="--",
    linewidth=2,
    label=label_Dataset_mean,
)

# Customizing the plot
ax.set_ylabel(ylabel_value, fontsize=12)
ax.set_xticklabels(categories, rotation=45, ha="right", fontsize=10)
ax.legend(fontsize=10)
ax.set_ylim(ylim_values)

# Title for the plot
ax.set_title(title, fontsize=14, fontweight="bold")

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout to prevent clipping of tick-labels
plt.tight_layout()
plt.savefig("errorpoint_52.pdf", bbox_inches="tight")
