
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

# Random seed for reproducibility
np.random.seed(42)

# Data in the heatmap (transportation systems)
data = np.array(
    [
        [0.65, 0.78, 0.82, 0.70, 0.66],
        [1.00, 0.68, 0.75, 0.60, 0.55],
        [np.nan, 1.00, 0.80, 0.85, 0.75],
        [np.nan, np.nan, 1.00, 0.92, 0.78],
        [np.nan, np.nan, np.nan, 1.00, 0.70],
        [np.nan, np.nan, np.nan, np.nan, 1.00],
    ]
)

# Labels for the rows and columns
row_labels = ["Average", "Buses", "Subways", "Trains", "Trams", "Ferries"]
col_labels = ["Buses", "Subways", "Trains", "Trams", "Ferries"]

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Create the figure and the axes
fig, ax = plt.subplots(figsize=(8, 8))

# Create the heatmap with an updated color map
cax = ax.matshow(data, cmap="Blues")

# Set the ticks
ax.set_xticks(np.arange(len(col_labels)))
ax.set_yticks(np.arange(len(row_labels)))

# Set the tick labels
ax.set_xticklabels(col_labels)
ax.set_yticklabels(row_labels)

# Rotate the tick labels and set their alignment
plt.setp(ax.get_xticklabels(), rotation=45, ha="left", rotation_mode="anchor")

# Move the row labels to the right side
ax.yaxis.tick_right()

# Loop over data dimensions and create text annotations
for i in range(len(row_labels)):
    for j in range(len(col_labels)):
        if not np.isnan(data[i, j]):
            text = ax.text(
                j, i, f"{data[i, j]:.2f}", ha="center", va="center", color="black"
            )

# Set the visibility of the spines
ax.spines["top"].set_visible(True)
ax.spines["right"].set_visible(True)
ax.spines["left"].set_visible(False)
ax.spines["bottom"].set_visible(False)

# Set the visibility of the ticks with only the top and right axes
ax.xaxis.set_ticks_position("top")
ax.yaxis.set_ticks_position("right")

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout and save the figure
plt.tight_layout()
plt.savefig("heatmap_31.pdf", bbox_inches="tight")
