
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)

# Define the data with correct shape
data = np.array(
    [
        [4.5, 2.3, 3.8, 5.0, np.nan, 4.2],
        [3.8, 4.9, 2.8, 4.1, 3.2, 4.5],
        [4.3, 3.4, np.nan, 2.7, 3.9, np.nan],
        [3.6, 4.1, 3.5, 4.8, 5.0, 3.4],
    ]
)

title = "Average Popularity Ratings of Genres on Streaming Platforms"
xlabel = "Genres"
xticklabels = ["Action", "Comedy", "Drama", "Horror", "Romance", "Sci-Fi"]
yticklabels = ["Netflix", "Hulu", "Amazon Prime", "Disney+"]

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Plotting the heatmap with adjusted colorbar and new theme color
# Create mask for NaN values to hatch them later
mask = np.isnan(data)

# Defining a new color palette
cmap = plt.get_cmap("viridis")
norm = plt.Normalize(vmin=np.nanmin(data), vmax=np.nanmax(data))

fig, ax = plt.subplots(figsize=(10, 8))
cax = ax.imshow(data, cmap=cmap, norm=norm)
cbar = fig.colorbar(cax, ax=ax, extend="both")

# Add hatches for NaN values
for i, j in zip(*np.where(mask)):
    ax.add_patch(
        plt.Rectangle(
            (j - 0.5, i - 0.5), 1, 1, fill=False, hatch="//", edgecolor="black"
        )
    )

# Adding titles and labels
plt.title(title, fontsize=16, fontweight='bold')
plt.xlabel(xlabel, fontsize=14)
plt.ylabel("Streaming Platforms", fontsize=14)

# Define the labels for x and y axis
ax.set_xticks(range(6))
ax.set_xticklabels(xticklabels, rotation=45, ha="right", fontsize=12)
ax.set_yticks(range(4))
ax.set_yticklabels(yticklabels, rotation=0, fontsize=12)

# Add annotations
for i in range(4):
    for j in range(6):
        if not np.isnan(data[i, j]):
            if data[i, j] > np.nanmean(data) * 1.2:
                ax.text(
                    j, i, f"{data[i, j]:.1f}", ha="center", va="center", color="white", fontweight="bold"
                )
            else:
                ax.text(
                    j, i, f"{data[i, j]:.1f}", ha="center", va="center", color="black"
                )

# ===================
# Part 4: Saving Output
# ===================
# Displaying the plot with tight layout to minimize white space
plt.tight_layout()
plt.savefig("heatmap_48.pdf", bbox_inches="tight")

