
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)

# Data for the heatmaps (Societal metrics for demonstration purposes)
data_education = np.random.rand(4, 4)
data_healthcare = np.random.rand(4, 4)
data_employment = np.random.rand(4, 4)
data_crime = np.random.rand(4, 4)

titles = ["Education", "Healthcare", "Employment", "Crime Rates"]
fig_title = "Societal Metrics"

xticklabels = ["Region A", "Region B", "Region C", "Region D"]
yticklabels = ["2018", "2019", "2020", "2021"]

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Create a figure with subplots
fig, axs = plt.subplots(2, 2, figsize=(10, 8))

# Function to add text annotations
def add_annotations(ax, data):
    for i in range(data.shape[0]):
        for j in range(data.shape[1]):
            ax.text(j, i, f"{data[i, j]:.2f}", ha="center", va="center", color="black")

# Education heatmap
im1 = axs[0, 0].imshow(data_education, cmap="Greens", vmin=0, vmax=1)
axs[0, 0].set_title(titles[0])
add_annotations(axs[0, 0], data_education)

# Healthcare heatmap
im2 = axs[0, 1].imshow(data_healthcare, cmap="Blues", vmin=0, vmax=1)
axs[0, 1].set_title(titles[1])
add_annotations(axs[0, 1], data_healthcare)

# Employment heatmap
im3 = axs[1, 0].imshow(data_employment, cmap="Purples", vmin=0, vmax=1)
axs[1, 0].set_title(titles[2])
add_annotations(axs[1, 0], data_employment)

# Crime Rates heatmap
im4 = axs[1, 1].imshow(data_crime, cmap="Reds", vmin=0, vmax=1)
axs[1, 1].set_title(titles[3])
add_annotations(axs[1, 1], data_crime)

# Adjust layout and add overall title
fig.suptitle(fig_title, fontsize=20)

# Set tick labels
for ax in axs.flat:
    ax.set_xticks(np.arange(4))
    ax.set_yticks(np.arange(4))
    ax.set_xticklabels(xticklabels)
    ax.set_yticklabels(yticklabels)

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout to minimize white space
plt.tight_layout(rect=[0, 0.03, 1, 0.95])
# Save the figure to a file
plt.savefig("heatmap_83.pdf", bbox_inches="tight")
