
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt


# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(42)
# Sample data for Sales Performance Analysis
achieved_sales = np.random.normal(loc=70, scale=10, size=1000)
target_sales = np.random.uniform(low=50, high=90, size=1000)

# Labels and Plot Types
hist_label = ["Achieved Sales", "Target Sales"]

# Axes Limits and Labels
xlabel_value = "Sales Amount (in thousands)"
ylabel_value = "Frequency"
title = "Sales Performance Analysis"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Set the figure size
plt.figure(figsize=(6, 5))

# Plot histograms with stacked bars, modified colors, and alpha for transparency
plt.hist(
    [achieved_sales, target_sales],
    bins=40,
    stacked=True,
    label=hist_label,
    color=["#2E8B57", "#1E90FF"],
    alpha=0.7,
)

# Add labels, title, and modify the style of the labels
plt.xlabel(xlabel_value, fontsize=12, color="#000000")
plt.ylabel(ylabel_value, fontsize=12, color="#000000")
plt.title(title, fontsize=14, fontweight='bold', color="#000000")

# Modify the legend style and position to upper right
plt.legend(frameon=True, loc="upper right", fontsize=10)

# Adjust x-axis range and add some space at the beginning of the x-axis
plt.xlim(left=40, right=100)  # Adjusted xlim for better visualization

# Add grid with lighter color and set behind the histograms
plt.grid(color="grey", linestyle="--", linewidth=0.5, alpha=0.7)
plt.gca().set_axisbelow(True)

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout and save the plot
plt.tight_layout()
plt.savefig("hist_66.pdf", bbox_inches="tight")
