
# ===================
# Part 1: Importing Libraries
# ===================

import matplotlib.pyplot as plt
from math import pi

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(42)

# Define the data for the radar chart
categories = [
    "Heating",
    "Cooling",
    "Lighting",
    "Ventilation",
    "Insulation",
    "Renewables",
    "Automation",
]
values1 = [7, 4, 6, 5, 8, 7, 6]  # Values for Residential Buildings
values2 = [8, 6, 5, 7, 6, 8, 7]  # Values for Commercial Buildings

# Number of variables
N = len(categories)

# Compute angle for each category
angles = [n / float(N) * 2 * pi for n in range(N)]
values1 += values1[:1]
values2 += values2[:1]
angles += angles[:1]

# Extracted variables
line_label1 = "Residential"
line_label2 = "Commercial"
xticks = angles[:-1]
xtickslabel = categories
yticks = [0, 2, 4, 6, 8, 10]
ytickslabel = ["0", "2", "4", "6", "8", "10"]
ylim = (0, 10)
legend_loc = "lower center"
legend_bbox_to_anchor = (0.5, 1.1)
legend_ncol = 2
legend_frameon = False

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Initialize the spider plot
fig, ax = plt.subplots(figsize=(6, 6), subplot_kw=dict(polar=True))

# Draw one axe per variable and add labels with increased padding
plt.xticks(xticks, xtickslabel, color="black", size=10)
ax.tick_params(pad=15)  # Increase the distance of the label from the axis

# Draw ylabels
ax.set_rlabel_position(0)
plt.yticks(yticks, ytickslabel, color="black", size=7)
plt.ylim(ylim)

# Plot data
ax.plot(
    angles, values1, linewidth=2, linestyle="dashed", label=line_label1, color="#2E86C1"
)
ax.fill(angles, values1, "#AED6F1", alpha=0.4)

ax.plot(
    angles, values2, linewidth=2, linestyle="solid", label=line_label2, color="#28B463"
)
ax.fill(angles, values2, "#A9DFBF", alpha=0.4)

# Add legend
plt.legend(
    loc=legend_loc,
    bbox_to_anchor=legend_bbox_to_anchor,
    ncol=legend_ncol,
    frameon=legend_frameon,
)

# Set the background color inside the radar chart to white
ax.set_facecolor("white")

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout for better fit
plt.tight_layout()

# Show the plot
plt.savefig("radar_53.pdf", bbox_inches="tight")
