
# ===================
# Part 1: Importing Libraries
# ===================
import matplotlib.pyplot as plt

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)
# Data
categories = [
    "Accommodation",
    "Transport",
    "Food",
    "Safety",
    "Attractions",
    "Infrastructure",
    "Affordability",
    "Weather",
    "Hospitality",
]
values1 = [78, 85, 88, 90, 95, 80, 70, 75, 85]  # Travel Agency A
values2 = [85, 78, 75, 85, 80, 90, 88, 82, 90]  # Travel Agency B

# Number of variables
num_vars = len(categories)

# Compute angle for each category
angles = np.linspace(0, 2 * np.pi, num_vars, endpoint=False).tolist()

# The plot is circular, so we need to "complete the loop" and append the start to the end.
values1 += values1[:1]
values2 += values2[:1]
angles += angles[:1]

# Extracted variables
line_label1 = "Travel Agency A"
line_label2 = "Travel Agency B"
xticks_labels = categories
yticks_values = [20, 40, 60, 80]
yticks_labels = []
ylim_values = (0, 100)
title_text = "Comparison of Travel Agencies in Tourism"
title_size = 14
title_color = "black"
title_y = 1.1
legend_loc = "lower center"
legend_ncol = 2
legend_bbox_to_anchor = (0.5, -0.2)
legend_fontsize = "small"
legend_frameon = False

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Size of the figure
fig, ax = plt.subplots(figsize=(8, 8), subplot_kw=dict(polar=True))

# Draw one axe per variable and add labels, aligned vertically
plt.xticks(angles[:-1], xticks_labels, color="black", size=10, ha="center")

# Draw ylabels
ax.set_rlabel_position(0)
plt.yticks(yticks_values, yticks_labels, color="grey", size=7)
plt.ylim(ylim_values)

# Plot data with markers and new colors
ax.plot(
    angles,
    values2,
    linewidth=2,
    linestyle="--",
    marker="o",
    label=line_label2,
    color="#1f77b4",  # Blueish color for Travel Agency B
)
ax.fill(angles, values2, "#1f77b4", alpha=0.2)

ax.plot(
    angles,
    values1,
    linewidth=2,
    linestyle="-",
    marker="s",
    label=line_label1,
    color="#2ca02c",  # Greenish color for Travel Agency A
)
ax.fill(angles, values1, "#2ca02c", alpha=0.2)

# Add a title to the radar chart
plt.title(title_text, size=title_size, color=title_color, y=title_y)

# Add legend
plt.legend(
    loc=legend_loc,
    ncol=legend_ncol,
    bbox_to_anchor=legend_bbox_to_anchor,
    fontsize=legend_fontsize,
    frameon=legend_frameon,
)

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout and save the plot
plt.tight_layout()
plt.savefig("radar_65.pdf", bbox_inches="tight")

