
# ===================
# Part 1: Importing Libraries
# ===================

import matplotlib.pyplot as plt
from math import pi

# ===================
# Part 2: Data Preparation
# ===================
import numpy as np

np.random.seed(0)

# Define the data for the radar chart. Categories related to environmental science.
categories = [
    "Air Quality",
    "Water Quality",
    "Biodiversity",
    "Energy Consumption",
    "Waste Management",
    "Green Spaces",
    "Renewable Energy",
    "Climate Action",
]
values1 = [7, 6, 5, 8, 7, 6, 8, 9]  # Values for Greenville
values2 = [6, 7, 7, 6, 8, 7, 7, 8]  # Values for Blueville
values3 = [8, 5, 6, 7, 6, 8, 6, 7]  # Values for Redville

# Number of variables
N = len(categories)

# Compute angle for each category
angles = [n / float(N) * 2 * pi for n in range(N)]
values1 += values1[:1]
values2 += values2[:1]
values3 += values3[:1]
angles += angles[:1]

# Extracted variables
xticks = angles[:-1]
xtickslabel = categories
yticks = [1, 3, 5, 7, 9]
ytickslabel = ["1", "3", "5", "7", "9"]
ylim = (0, 10)
line_label1 = "Greenville"
line_label2 = "Blueville"
line_label3 = "Redville"

# ===================
# Part 3: Plot Configuration and Rendering
# ===================
# Initialize the spider plot
fig, ax = plt.subplots(figsize=(6, 6), subplot_kw=dict(polar=True))

# Draw one axe per variable and add labels
plt.xticks(xticks, xtickslabel, color="darkgreen", size=8)
ax.tick_params(pad=15)  # Adjust the distance of the label from the axis

# Draw ylabels
ax.set_rlabel_position(30)
plt.yticks(yticks, ytickslabel, color="darkblue", size=7)
plt.ylim(ylim)

# Plot data
ax.plot(
    angles, values1, linewidth=2, linestyle="dotted", label=line_label1, color="forestgreen"
)
ax.fill(angles, values1, color="lightgreen", alpha=0.25)

ax.plot(
    angles, values2, linewidth=2, linestyle="dashed", label=line_label2, color="royalblue"
)
ax.fill(angles, values2, color="lightblue", alpha=0.25)

ax.plot(
    angles, values3, linewidth=2, linestyle="solid", label=line_label3, color="brown"
)
ax.fill(angles, values3, color="sandybrown", alpha=0.25)

# Add legend
plt.legend(loc="upper right", bbox_to_anchor=(1.2, 1.2), ncol=1, frameon=False)

# Set the background color inside the radar chart to white
ax.set_facecolor("white")

# ===================
# Part 4: Saving Output
# ===================
# Adjust layout for better fit
plt.tight_layout()

plt.savefig("radar_76.pdf", bbox_inches="tight")

